==> haskell-tagstream-conduit-0.5.5.3-267-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-tagstream-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tagstream-conduit
version: 0.5.5.3
id: tagstream-conduit-0.5.5.3-QnPPZ5YLKO7Di6sqi3n3b
key: tagstream-conduit-0.5.5.3-QnPPZ5YLKO7Di6sqi3n3b
license: BSD-3-Clause
maintainer: yi.codeplayer@gmail.com
author: yihuang
homepage: http://github.com/yihuang/tagstream-conduit
synopsis: streamlined html tag parser
description:
    Tag-stream is a library for parsing HTML//XML to a token stream.
    It can parse unstructured and malformed HTML from the web.
    It also provides an Enumeratee which can parse streamline html, which means it consumes constant memory.
    You can start from the `tests/Tests.hs` module to see what it can do.
category: Web, Conduit
abi: f4515c00a862560d6b81a380435e7ead
exposed: True
exposed-modules:
    Text.HTML.TagStream Text.HTML.TagStream.ByteString
    Text.HTML.TagStream.Entities Text.HTML.TagStream.Text
    Text.HTML.TagStream.Types Text.HTML.TagStream.Utils
import-dirs: /usr/lib/ghc-8.6.5/site-local/tagstream-conduit-0.5.5.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/tagstream-conduit-0.5.5.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/tagstream-conduit-0.5.5.3
hs-libraries: HStagstream-conduit-0.5.5.3-QnPPZ5YLKO7Di6sqi3n3b
depends:
    attoparsec-0.13.2.2-EdUct2wsQri8X0bjC24wTV base-4.12.0.0
    blaze-builder-0.4.1.0-KrFxFv3kgua3BTNMsMBadC bytestring-0.10.8.2
    case-insensitive-1.2.1.0-L7BR5PaOPZy5cAHpLYQKhk
    conduit-1.3.1.1-GP6MsgQ2BS48W03o5Iyugz
    conduit-extra-1.3.1.1-BpNAtWN1v251tAneLnGOdO
    data-default-0.7.1.1-GQk9Hqcpzml6dpaWfistUm
    resourcet-1.2.2-DSV6hnFiraKK5yk15oWe4c text-1.2.3.1
    transformers-0.5.6.2 xml-conduit-1.8.0.1-40yXKJJvw1C69AojaD351p
haddock-interfaces: /usr/share/doc/haskell-tagstream-conduit/html/tagstream-conduit.haddock
haddock-html: /usr/share/doc/haskell-tagstream-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tagstream-conduit-0.5.5.3-270-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-tagstream-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tagstream-conduit
version: 0.5.5.3
id: tagstream-conduit-0.5.5.3-C2RAAvVSGwVKtfsADBBqU3
key: tagstream-conduit-0.5.5.3-C2RAAvVSGwVKtfsADBBqU3
license: BSD-3-Clause
maintainer: yi.codeplayer@gmail.com
author: yihuang
homepage: http://github.com/yihuang/tagstream-conduit
synopsis: streamlined html tag parser
description:
    Tag-stream is a library for parsing HTML//XML to a token stream.
    It can parse unstructured and malformed HTML from the web.
    It also provides an Enumeratee which can parse streamline html, which means it consumes constant memory.
    You can start from the `tests/Tests.hs` module to see what it can do.
category: Web, Conduit
abi: 83bc4c2c39bbed86065f3922ad78ba4e
exposed: True
exposed-modules:
    Text.HTML.TagStream Text.HTML.TagStream.ByteString
    Text.HTML.TagStream.Entities Text.HTML.TagStream.Text
    Text.HTML.TagStream.Types Text.HTML.TagStream.Utils
import-dirs: /usr/lib/ghc-8.6.5/site-local/tagstream-conduit-0.5.5.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/tagstream-conduit-0.5.5.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/tagstream-conduit-0.5.5.3
hs-libraries: HStagstream-conduit-0.5.5.3-C2RAAvVSGwVKtfsADBBqU3
depends:
    attoparsec-0.13.2.2-EdUct2wsQri8X0bjC24wTV base-4.12.0.0
    blaze-builder-0.4.1.0-KrFxFv3kgua3BTNMsMBadC bytestring-0.10.8.2
    case-insensitive-1.2.1.0-L7BR5PaOPZy5cAHpLYQKhk
    conduit-1.3.1.1-7rGn2miUuc0IzsMPA6GM7m
    conduit-extra-1.3.2-2xarBShtmoTHDN9knVQRhr
    data-default-0.7.1.1-GQk9Hqcpzml6dpaWfistUm
    resourcet-1.2.2-DSV6hnFiraKK5yk15oWe4c text-1.2.3.1
    transformers-0.5.6.2 xml-conduit-1.8.0.1-8MXzW7xTcm22arw6gZZFxO
haddock-interfaces: /usr/share/doc/haskell-tagstream-conduit/html/tagstream-conduit.haddock
haddock-html: /usr/share/doc/haskell-tagstream-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
